[−][src]Struct aws_arn::builder::ResourceBuilder
Builder type for the resource portion of an ARN.
Methods
impl ResourceBuilder[src]
pub fn new(id: &str) -> Self[src]
Construct a resource with the specified id.
pub fn any() -> Self[src]
Construct a resource with a wildcard id.
pub fn is_a(&mut self, the_type: &str) -> &mut Self[src]
Add the specific type to this resource (path-like style).
pub fn is_an(&mut self, the_type: &str) -> &mut Self[src]
Add the specific type to this resource (path-like style).
pub fn has_type(&mut self, the_type: &str) -> &mut Self[src]
Add the specific type to this resource (path-like style).
pub fn with(&mut self, qualifier: &str) -> &mut Self[src]
Add a qualifier to this resource
pub fn with_version(&mut self, version: i32) -> &mut Self[src]
Add a version number, as a qualifier, to this resource
pub fn build(&self) -> Resource[src]
Construct a Resource from this ResourceBuilder.